@@ -2,6 +2,7 @@
 ## functions for argument checking
 
 
+
 ##' Validator functions for umap settings
 ##'
 ##' @keywords internal
@@ -10,6 +11,8 @@
 ##'
 ##' @return config object, may contain some different components from config in input
 umap.check.config = function(config=umap.defaults, ...) {
+
+  umap.check.config.class(config)
   
   ## transfer values from arguments into the config object
   arguments = list(...)
@@ -17,15 +20,20 @@ umap.check.config = function(config=umap.defaults, ...) {
     config[[onearg]] = arguments[[onearg]]
   }
 
+  missing = setdiff(names(umap.defaults), names(config))
+  if (length(missing)>0) {
+    umap.error(paste0("missing arguments: ", paste(missing, collapse=", ")))
+  }
+
   ## manual adjustments on some settings
-  config$n.neighbors = ceiling(config$n.neighbors)
+  config$n_neighbors = ceiling(config$n_neighbors)
 
   ## checks on individual parameters
-  if (config$n.neighbors<2) {
+  if (config$n_neighbors<2) {
     umap.error("number of neighbors must be greater than 1")
   }
 
-  if (!is.finite(config$n.epochs) | config$n.epochs<0) {
+  if (!is.finite(config$n_epochs) | config$n_epochs<0) {
     umap.error("number of epochs must be positive")
   }
 
@@ -33,31 +41,32 @@ umap.check.config = function(config=umap.defaults, ...) {
     umap.error("setting 'data' must be either 'data' or 'dist'")
   }
 
-  if (!is.finite(config$local.connectivity) | config$local.connectivity <= 0) {
-    umap.error("setting 'local.connectivity' must be >= 0")
+  if (!is.finite(config$local_connectivity) | config$local_connectivity <= 0) {
+    umap.error("setting 'local_connectivity' must be >= 0")
   }
 
   ## force some data types
-  for (x in c("n.epochs", "n.neighbors", "n.components",
-              "seed", "negative.sample.rate")) {
+  for (x in c("n_epochs", "n_neighbors", "n_components",
+              "random_state", "negative_sample_rate", "transform_state")) {
     config[[x]] = as.integer(config[[x]])
   }
   
   ## always give a metric name
-  config$metric.name = "custom"
-  ## replace a distance description by a function
-  if (class(config$metric.function)!="function") {
-    config$metric.name = config$metric.function
+  if (class(config$metric)=="function") {
+    config$metric.function = config$metric
+    config$metric = "custom"
+  } else {
+    ## replace a distance description by a function
     available.metrics = c(manhattan=mdManhattan,
                           pearson2=mdCenteredPearson, ## relies on centering during prep
                           pearson=mdCosine, ## relies on centering during prep
                           cosine=mdCosine,
                           euclidean=mdEuclidean)
-    if (config$metric.function %in% names(available.metrics)) {
-      config$metric.function = available.metrics[[config$metric.function]]
+    if (config$metric %in% names(available.metrics)) {
+      config$metric.function = available.metrics[[config$metric]]
     } else {
-      if (config$method != "python") {
-        umap.error("unrecognized distance description: ", config$metric.function)
+      if (config$method != "umap-learn") {
+        umap.error("unrecognized distance description: ", config$metric)
       }
     }
   }
@@ -85,9 +94,11 @@ umap.prep.input = function(d, config) {
   } else {
     umap.error("input must be a matrix or matrix-compatible\n")
   }
+  ## ensure data is numeric (not integer or other data type)
+  d[,1] = as.numeric(d[,1])
   
   ## perhaps adjust the data matrix
-  if (config$metric.name %in% c("pearson", "pearson2")) {
+  if (config$metric %in% c("pearson", "pearson2")) {
     ## for pearson correlation distance, center by-sample
     ## (this avoids computing means during correlations)
     d = t(d)
@@ -109,3 +120,14 @@ umap.error = function(...) {
   stop(paste0("umap: ", x, "\n"), call.=FALSE)
 }
 
+
+##' Validator for config class component
+##'
+##' @keywords internal
+##' @param config list with arguments (object of class umap.config)
+umap.check.config.class = function(config) {
+  if (class(config)!="umap.config") {
+    umap.error("config is absent or corrupt")
+  }
+}
+
